Index: sys/dev/fdt/simplebus.c
===================================================================
--- sys/dev/fdt/simplebus.c	(revision 262447)
+++ sys/dev/fdt/simplebus.c	(working copy)
@@ -161,16 +161,61 @@
 	struct simplebus_devinfo *di;
 	struct simplebus_softc *sc;
 	phandle_t dt_node, dt_child;
+#define PROBE_UNORDERED INT32_MIN
+	int32_t probe_order;
+	struct sortq_entry {
+		TAILQ_ENTRY(sortq_entry) link;
+		int32_t probe_order;
+		phandle_t dt_child;
+	} *new_sqe, *sqe, *sqe_tmp;
+	TAILQ_HEAD(sortq_head, sortq_entry) sq = TAILQ_HEAD_INITIALIZER(sq);
 
 	sc = device_get_softc(dev);
 
 	/*
-	 * Walk simple-bus and add direct subordinates as our children.
+	 * Walk simple-bus and queue direct subordinates to be added as our
+	 * children below, respecting any specified probe ordering.
 	 */
 	dt_node = ofw_bus_get_node(dev);
 	for (dt_child = OF_child(dt_node); dt_child != 0;
 	    dt_child = OF_peer(dt_child)) {
 
+		new_sqe = malloc(sizeof(*sqe), M_SIMPLEBUS, M_WAITOK);
+		new_sqe->dt_child = dt_child;
+
+		/*
+		 * Preserve the existing order, unless this child has a
+		 * specified probe-order and it is less than the specified
+		 * probe order of a previous child, in which case this child
+		 * is inserted just prior to that previous child.
+		 */
+		if (OF_getprop(dt_child, "probe-order", &probe_order, sizeof(probe_order)) > 0) {
+			new_sqe->probe_order = (int32_t)fdt_data_get(&probe_order, 1);
+
+			TAILQ_FOREACH(sqe, &sq, link) {
+				if ((PROBE_UNORDERED != sqe->probe_order) &&
+				    (new_sqe->probe_order < sqe->probe_order)) {
+					TAILQ_INSERT_BEFORE(sqe, new_sqe, link);
+					break;
+				}
+			}
+
+			if (NULL == sqe) {
+				TAILQ_INSERT_TAIL(&sq, new_sqe, link);
+			}
+		} else {
+			new_sqe->probe_order = PROBE_UNORDERED;
+			TAILQ_INSERT_TAIL(&sq, new_sqe, link);
+		}
+	}
+
+	/*
+	 * Add the queued subordinates as children.
+	 */
+	TAILQ_FOREACH_SAFE(sqe, &sq, link, sqe_tmp) {
+		dt_child = sqe->dt_child;
+		free(sqe, M_SIMPLEBUS);
+
 		/* Check and process 'status' property. */
 		if (!(fdt_is_enabled(dt_child)))
 			continue;
